<template>
    <div class="system-add-menu-container">
        <el-dialog v-model="ifShowApproveRuleDialog" :title="title">
            <el-form :model="approveRuleForm" label-width="120px" ref="approveRuleFormRef" :rules="approveRuleFormRules">
                <el-row>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="任务名称" prop="ruleName">
                            <el-input v-model="approveRuleForm.ruleName" :disabled="!inspectPointConfirm" class="input-add" placeholder="请填写任务名称"> </el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="部门名称" prop="depId">
                            <el-cascader :disabled="!inspectPointConfirm" placeholder="请选择部门名称" :options="departmentList" :props="{ emitPath: false, checkStrictly: true, value: 'depId', label: 'depName' }" clearable filterable class="input-add" v-model="approveRuleForm.depId"> </el-cascader>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="作业类型" prop="workType">
                            <el-select v-model="approveRuleForm.workType" :disabled="!inspectPointConfirm" placeholder="请选择作业类型" class="input-add">
                                <el-option v-for="item in workTypeList" :key="item.id" :value="item.id" :label="item.name"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :span="12" style="margin-bottom: 20px">
                        <el-form-item label="作业等级" prop="workLevel">
                            <el-select v-model="approveRuleForm.workLevel" :disabled="!inspectPointConfirm" placeholder="请选择作业等级" class="input-add">
                                <el-option v-for="item in workLevelList" :key="item.id" :value="item.id" :label="item.groupName"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>

                    <el-col :span="24">
                        <el-form-item label="创建审批链">
                            <div style="width: 100%; margin-bottom: 20px" v-show="inspectPointConfirm">
                                <el-button type="primary" :icon="Plus" size="default" @click="openApproveLevelDialog('新增', '')">新增巡检点</el-button>
                            </div>
                            <div style="width: 100%; margin-left: -30px">
                                <div v-for="(item, index) in approveRuleForm.stepAddReqDTOList" class="stepItem">
                                    <div class="stepNum">{{ index + 1 }}</div>
                                    <div class="stepCard">
                                        <el-card class="box-card">
                                            <div class="text item">
                                                层级名称：<span>{{ item.stepName }}</span>
                                            </div>
                                            <!--                                            <div class="text item">-->
                                            <!--                                                所属设备区域：<span>{{ item.regionId }}</span>-->
                                            <!--                                            </div>-->
                                            <div class="text item">
                                                审批类型：<span>{{ item.type }}</span>
                                            </div>
                                            <!--                                            <div class="text item">-->
                                            <!--                                                关联RFID：<span>{{ item.rfidId }}</span>-->
                                            <!--                                            </div>-->
                                            <div class="text item">
                                                审批人：<span>{{ item.type }}</span>
                                            </div>
                                            <!--                                            <div class="text item">-->
                                            <!--                                                巡检指标：<span>{{ item.quotaId }}</span>-->
                                            <!--                                            </div>-->
                                            <div class="text item">
                                                审批有效时长：<span>{{ item.name }}</span>
                                            </div>
                                            <!--                                            <div class="text item">-->
                                            <!--                                                数据填报类型：<span>{{ item.dataReportType }}</span>-->
                                            <!--                                            </div>-->
                                            <div class="text item">
                                                审批项：<span>{{ item.firstReferenceValue ? item.firstReferenceValue : item.secondReferenceValue ? item.secondReferenceValue : item.thirdReferenceValue }}</span>
                                            </div>
                                        </el-card>
                                    </div>
                                    <div v-show="inspectPointConfirm">
                                        <!--								<el-button type="primary" size="default" @click="addFlow(index)">新增下一区域</el-button>-->
                                        <el-button type="primary" style="margin-left: 12px" size="default" @click="openApproveLevelDialog('修改', item)">修改</el-button>
                                        <el-button type="danger" size="default" @click="deleteApproveLevel(index, item)">删除</el-button>
                                    </div>
                                </div>
                            </div>
                        </el-form-item>
                    </el-col>
                </el-row>
                <div align="right" v-show="inspectPointConfirm">
                    <el-button type="warning" @click="inspectPointDialog = false" size="default" plain>取消</el-button>
                    <el-button type="primary" @click="submitApproveRule()" size="default">确认</el-button>
                </div>
            </el-form>
        </el-dialog>
        <approve-level-dialog ref="approveLevelDialogRef" @addApprovalLevel="achieveApprovalLevel"></approve-level-dialog>
    </div>
</template>

<script lang="ts">
import { reactive, toRefs, ref } from 'vue';
import { ElMessage } from 'element-plus/es';
import { approveRuleApi } from '/@/api/specialWorkSystem/approveRule';
import approveLevelDialog from '/@/views/specialWorkSystem/workFlow/approveRule/components/approveLevelDialog.vue';
interface dataState {
    title: string;
    pointTitle: string;
    inspectPointConfirm: boolean;
    inspectPointDialog: boolean;
    ifShowApproveRuleDialog: boolean;
    inspectPointForm: stepAddReqDTO;
    approveRuleForm: {
        id: number | null;
        ruleName: number | null;
        depId: number | null;
        workType: number | null;
        workLevel: number | null;
        stepAddReqDTOList: Array<stepAddReqDTO>;
    };
    approveRuleFormRules: {};
    departmentList: [];
    userList: [];
    workTypeList: [];
    workLevelList: [];
}

interface quota {
    id: number;
    type: string;
    unit: string;
}
interface stepAddReqDTO {
    id: number | null;
    stepName: null;
    stepSerial: number | null;
    type: number | null;
    continueTime: number | null;
    continueTimeUnit: number | null;
    unitAddReqDTOList: [];
    itemAddReqDTOList: [];
}
export default {
    name: 'approveRuleDialog',
    components: { approveLevelDialog },
    setup(props: any, context: any) {
        const approveRuleFormRef = ref();
        const approveLevelDialogRef = ref();
        const data = reactive<dataState>({
            title: '',
            pointTitle: '',
            inspectPointConfirm: true,
            inspectPointDialog: false,
            ifShowApproveRuleDialog: false,
            inspectPointForm: {
                id: null,
                stepName: null,
                stepSerial: null,
                type: null,
                continueTime: null,
                continueTimeUnit: null,
                unitAddReqDTOList: [],
                itemAddReqDTOList: []
            },
            approveRuleForm: {
                id: null,
                ruleName: null,
                depId: null,
                workType: null,
                workLevel: null,
                stepAddReqDTOList: []
            },
            approveRuleFormRules: {
                unitName: [{ required: true, message: '请填写巡检任务单元名称', trigger: 'blur' }],
                workType: [{ required: true, message: '请选择巡检任务类型', trigger: 'change' }],
                execClassgroupId: [{ required: true, message: '请选择巡检班组', trigger: 'change' }],
                execDepId: [{ required: true, message: '请选择巡检部门', trigger: 'blur' }],
                checkCycle: [{ required: true, message: '请填写巡检周期', trigger: 'blur' }],
                noticeTime: [{ required: true, message: '请填写提前通知时间', trigger: 'blur' }],
                validTime: [{ required: true, message: '请填写有效时间', trigger: 'blur' }],
                firstStartTime: [{ required: true, message: '请选择周期开始时间', trigger: 'change' }]
            },
            departmentList: [],
            userList: [],
            workTypeList: [],
            workLevelList: []
        });

        const openApproveLevelDialog = (type: string, value: {}) => {
            approveLevelDialogRef.value.showApproveLevelDialog(type, value, data.userList);
        };

        const achieveApprovalLevel = (value: stepAddReqDTO, title: string) => {
            debugger;
            if (title === '新增审批层级') {
                if (data.approveRuleForm.stepAddReqDTOList.length === 0) {
                    value.stepSerial = 1;
                    data.approveRuleForm.stepAddReqDTOList.push(value);
                } else {
                    value.stepSerial = data.approveRuleForm.stepAddReqDTOList[data.approveRuleForm.stepAddReqDTOList.length - 1].stepSerial + 1;
                    data.approveRuleForm.stepAddReqDTOList.push(value);
                }
            } else {
                let result = data.approveRuleForm.stepAddReqDTOList.findIndex((item) => item.stepSerial === value.stepSerial);
                data.approveRuleForm.stepAddReqDTOList[result] = JSON.parse(JSON.stringify(value));
            }
        };

        const showApproveRuleDialog = (type: string, value: {}, departmentList: [], userList: [], workTypeList: []) => {
            data.ifShowApproveRuleDialog = true;
            data.userList = userList;
            data.workTypeList = workTypeList;
            data.departmentList = departmentList;
            if (type === '新增') {
                data.title = '新增审批规则';
                data.approveRuleForm = {
                    id: null,
                    ruleName: null,
                    depId: null,
                    workType: null,
                    workLevel: null,
                    stepAddReqDTOList: []
                };
            } else {
                data.title = '修改审批规则';
                data.approveRuleForm = JSON.parse(JSON.stringify(value));
            }
        };

        const deleteApproveLevel = (index: number, item: any) => {
            data.approveRuleForm.stepAddReqDTOList.splice(index, 1);
        };

        const submitApproveRule = () => {
            approveRuleFormRef.value.validate(async (valid: Boolean) => {
                if (valid) {
                    if (data.title === '新增审批规则') {
                        let res = await approveRuleApi().addApproveRule(data.approveRuleForm);
                        if (res.data.code === '200') {
                            ElMessage({
                                type: 'success',
                                message: '审批规则新增成功',
                                duration: 2000
                            });
                            data.ifShowApproveRuleDialog = false;
                            context.emit('refreshApproveRule');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    } else {
                        let res = await approveRuleApi().modApproveRule(data.approveRuleForm);
                        if (res.data.code === '200') {
                            ElMessage({
                                type: 'success',
                                message: '审批规则修改成功',
                                duration: 2000
                            });
                            data.ifShowApproveRuleDialog = false;
                            context.emit('refreshApproveRule');
                        } else {
                            ElMessage({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    }
                } else {
                    ElMessage({
                        type: 'warning',
                        message: '请完善基本信息'
                    });
                }
            });
        };

        return {
            ...toRefs(data),
            approveLevelDialog,
            approveRuleFormRef,
            approveLevelDialogRef,
            submitApproveRule,
            achieveApprovalLevel,
            openApproveLevelDialog,
            showApproveRuleDialog,
            deleteApproveLevel
        };
    }
};
</script>

<style scoped lang="scss">
$homeNavLengh: 8;
.home-container {
    height: calc(100vh - 144px);
    box-sizing: border-box;
    overflow: hidden;
    .homeCard {
        width: 100%;
        padding: 20px;
        box-sizing: border-box;
        background: #fff;
        border-radius: 4px;

        .main-card {
            width: 100%;
            height: 100%;
            .cardTop {
                display: flex;
                align-items: center;
                justify-content: space-between;
                margin-bottom: 20px;
                .mainCardBtn {
                    margin: 0;
                }
            }
            .pageBtn {
                height: 60px;
                display: flex;
                align-items: center;
                justify-content: right;

                .demo-pagination-block + .demo-pagination-block {
                    margin-top: 10px;
                }
                .demo-pagination-block .demonstration {
                    margin-bottom: 16px;
                }
            }
        }
        &:last-of-type {
            height: calc(100% - 100px);
        }
    }
    .el-row {
        display: flex;
        align-items: center;
        margin-bottom: 20px;
        &:last-child {
            margin-bottom: 0;
        }
        .grid-content {
            align-items: center;
            min-height: 36px;
        }

        .topInfo {
            display: flex;
            align-items: center;
            font-size: 16px;
            font-weight: bold;

            & > div {
                white-space: nowrap;
                margin-right: 20px;
            }
        }
    }
}
.stepItem {
    width: 100%;
    display: flex;
    align-items: flex-start;
    margin-bottom: 30px;
    margin-left: 30px;
    padding-bottom: 30px;
    border-left: 2px solid #ccc;
    &:first-of-type {
        margin-top: 30px;
    }
    &:last-of-type {
        margin-bottom: 0;
        border-left: none;
    }
    .stepNum {
        width: 30px;
        height: 30px;
        border-radius: 15px;
        box-sizing: border-box;
        color: #333;
        border: 1px solid #999;
        line-height: 28px;
        text-align: center;
        margin-right: 10px;
        margin-left: -16px;
        margin-top: -30px;
    }
    .stepCard {
        width: 100%;
        margin-top: -30px;

        .box-card {
            width: 100%;
            &:deep(.el-card__header) {
                padding: 10px 15px;
            }
            .card-header {
                width: 100%;
                display: flex;
                justify-content: space-between;
                align-items: center;
                & > div:first-of-type {
                    margin-right: 80px;
                    font-size: 18px;
                    font-weight: bold;
                }
            }
        }
    }
    &:hover .card-header {
        color: #0098f5;
    }
    &:hover .stepNum {
        border: 2px solid #0098f5;
        color: #0098f5;
    }
}
:deep(.el-date-editor) {
    width: 100%;
}
</style>
